// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include "bomber.hh"
#include "../globals.hh"
#include "../SoundSpecs.hh"

PinguAction*
make_Bomber()
{
  return new Bomber;
}

Bomber::Bomber()
{
  particle_thrown = false;
  surface = CL_Res_Surface::load("Pingus/bomber", *resource());
  counter.set_size(surface->get_no_sprs());
  counter.set_type(Counter::once);
  counter.set_count(0);
  counter.set_speed(10);
  is_multi_direct = false;
  environment = (PinguEnvironment)(land | sky) ; 
  if (sound_enabled) SoundSpecs::play(SoundSpecs::OHNO);
}

void
Bomber::let_move()
{
  if (data->status == dead)
    return;
  // Bug: This only needs to set once, but in the constructor data is
  // not initialisised 
  data->status = not_catchable;
  // BugEnd

  // Pingu explode
  if (sound_enabled && counter == 10) {
    SoundSpecs::play(SoundSpecs::EXPLODE);
  }

  if (counter > 12 && !particle_thrown) {
    particle_thrown = true;
    data->particle->add_pingu_explo(data->x_pos, data->y_pos - 16);
  }

  // The pingu explode
  if (counter >= surface->get_no_sprs() - 1) {
    data->status = dead;
    // Remove some ground
    for(int y=data->y_pos - 16; y < data->y_pos + 16 ; ++y)
      for(int x=data->x_pos - 16; x < data->x_pos + 16 ; ++x) {
	colmap->remove(x, y);
	map->remove(x, y);
      }
  }
}

/* EOF */
